# Hartufo
A Python toolkit for data-driven HRTF research

## Installation

The `hartufo` package is configured to be installable with `pip`, so you can simply run `pip install [--user] hartufo`.

## Mailing List

In order to be kept up to date with the latest developments and new releases, subscribe to the mailing list by sending an email to [sympa@qmul.ac.uk](mailto:sympa@qmul.ac.uk?subject=subscribe%20hartufo-users%20FirstName%20LastName) with subject `subscribe hartufo-users FirstName LastName` and an empty body (clicking on the email address will preformat this message for you). Don't forget to replace the placeholders with your own name.

### Development Setup
To contribute, it is best to check out the repo and install it in "editable mode" with the following procedure.

- `git clone https://github.com/jpauwels/hartufo/`
- `cd hartufo`
- `pip install [--user] -e .`

You can then simply update the package by calling `git pull` whenever the repo has been updated or even make your own edits and start contributing.
